==> surveyplat-proof-common-nfzd-1.0.0-20200930.123212-7-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzYhxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * Created by Administrator on 2018/5/2.
 * 用户信息表
 */
@Table(name = "dcjz_yhxx")
public class DcjzYhxx {

    @Id
    //主键
    private String yhxxid;

    //用户密码
    private String yhmm;

    //用户姓名
    private String yhxm;

    //行政区代码
    private String xzqdm;

    //行政区名称
    private String xzqmc;

    //角色(1：管理员 2：普通用户 3：核检人员)
    private String yhjs;

    //级别（1：省 2：市 3：县）
    private String jb;

    //备注
    private String bz;

    //用户单位
    private String yhdw;

    //状态 0代表注销
    private String zt;

    //是否为管理员
    private String gly;

    // 实名注册
    private String xm;

    // 身份证号
    private String sfzh;

    // 性别
    private String gender;

    // 手机号
    private String sjh;

    // 邮箱
    private String email;

    // 审核状态
    private String shzt;

    // 审核说明
    private String shsm;

    public String getShsm() {
        return shsm;
    }

    public void setShsm(String shsm) {
        this.shsm = shsm;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getGender() {
        return gender;
    }

    public void setGender(String gender) {
        this.gender = gender;
    }

    public String getSjh() {
        return sjh;
    }

    public void setSjh(String sjh) {
        this.sjh = sjh;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getGly() {
        return gly;
    }

    public void setGly(String gly) {
        this.gly = gly;
    }

    public String getYhdw() {
        return yhdw;
    }

    public void setYhdw(String yhdw) {
        this.yhdw = yhdw;
    }

    public String getYhxxid() {
        return yhxxid;
    }

    public void setYhxxid(String yhxxid) {
        this.yhxxid = yhxxid;
    }

    public String getYhmm() {
        return yhmm;
    }

    public void setYhmm(String yhmm) {
        this.yhmm = yhmm;
    }

    public String getYhxm() {
        return yhxm;
    }

    public void setYhxm(String yhxm) {
        this.yhxm = yhxm;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getYhjs() {
        return yhjs;
    }

    public void setYhjs(String yhjs) {
        this.yhjs = yhjs;
    }

    public String getJb() {
        return jb;
    }

    public void setJb(String jb) {
        this.jb = jb;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }
}

==> surveyplat-proof-common-nfzd-1.0.0-20211019.031030-14-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzYhxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * Created by Administrator on 2018/5/2.
 * 用户信息表
 */
@Table(name = "dtxx_yhxx")
public class DcjzYhxx {

    @Id
    //主键
    private String yhxxid;

    //用户密码
    private String yhmm;

    //用户姓名
    private String yhxm;

    //行政区代码
    private String xzqdm;

    //行政区名称
    private String xzqmc;

    //角色(1：管理员 2：普通用户 3：核检人员)
    private String yhjs;

    //级别（1：省 2：市 3：县）
    private String jb;

    //备注
    private String bz;

    //用户单位
    private String yhdw;

    //状态 0代表注销
    private String zt;

    //是否为管理员
    private String gly;

    // 实名注册
    private String xm;

    // 身份证号
    private String sfzh;

    // 性别
    private String gender;

    // 手机号
    private String sjh;

    // 邮箱
    private String email;

    // 审核状态
    private String shzt;

    //用户权限 0可以进入销号系统，其他不可以进入销号系统
    private String yhqx;

    // 审核说明
    private String shsm;

    // 用户部门
    private String yhbm;

    public String getYhbm() {
        return yhbm;
    }

    public void setYhbm(String yhbm) {
        this.yhbm = yhbm;
    }

    public String getYhqx() {
        return yhqx;
    }

    public void setYhqx(String yhqx) {
        this.yhqx = yhqx;
    }

    public String getShsm() {
        return shsm;
    }

    public void setShsm(String shsm) {
        this.shsm = shsm;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getGender() {
        return gender;
    }

    public void setGender(String gender) {
        this.gender = gender;
    }

    public String getSjh() {
        return sjh;
    }

    public void setSjh(String sjh) {
        this.sjh = sjh;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getGly() {
        return gly;
    }

    public void setGly(String gly) {
        this.gly = gly;
    }

    public String getYhdw() {
        return yhdw;
    }

    public void setYhdw(String yhdw) {
        this.yhdw = yhdw;
    }

    public String getYhxxid() {
        return yhxxid;
    }

    public void setYhxxid(String yhxxid) {
        this.yhxxid = yhxxid;
    }

    public String getYhmm() {
        return yhmm;
    }

    public void setYhmm(String yhmm) {
        this.yhmm = yhmm;
    }

    public String getYhxm() {
        return yhxm;
    }

    public void setYhxm(String yhxm) {
        this.yhxm = yhxm;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getYhjs() {
        return yhjs;
    }

    public void setYhjs(String yhjs) {
        this.yhjs = yhjs;
    }

    public String getJb() {
        return jb;
    }

    public void setJb(String jb) {
        this.jb = jb;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }
}
